@@ -1,5 +1,3 @@
-/* $XFree86$ */
-/* $XdotOrg: driver/xf86-video-sis/src/sis_dac.c,v 1.23 2005/07/13 17:17:00 twini Exp $ */
 /*
  * DAC helper functions (Save/Restore, MemClk, etc)
  *
@@ -545,8 +543,8 @@ SiS300Save(ScrnInfoPtr pScrn, SISRegPtr sisReg)
 
     /* Save FQBQ and GUI timer settings */
     if(pSiS->Chipset == PCI_CHIP_SIS630) {
-       sisReg->sisRegsPCI50 = pciReadLong(0x00000000, 0x50);
-       sisReg->sisRegsPCIA0 = pciReadLong(0x00000000, 0xA0);
+       sisReg->sisRegsPCI50 = sis_pci_read_host_bridge_u32(0x50);
+       sisReg->sisRegsPCIA0 = sis_pci_read_host_bridge_u32(0xA0);
 #ifdef TWDEBUG
        xf86DrvMsg(pScrn->scrnIndex, X_INFO,
 		"PCI Config 50 = %lx\n", sisReg->sisRegsPCI50);
@@ -603,7 +601,7 @@ SiS300Restore(ScrnInfoPtr pScrn, SISRegPtr sisReg)
     if(!(pSiS->UseVESA)) {
        if(pSiS->VBFlags2 & VB2_LVDS) {
 	  SiSRegInit(pSiS->SiS_Pr, pSiS->RelIO + 0x30);
-	  SiSSetLVDSetc(pSiS->SiS_Pr, 0);
+	  SiSSetLVDSetc(pSiS->SiS_Pr);
 	  SiS_GetVBType(pSiS->SiS_Pr);
 	  SiS_UnLockCRT2(pSiS->SiS_Pr);
 	  SiS_DisableBridge(pSiS->SiS_Pr);
@@ -687,9 +685,9 @@ SiS300Restore(ScrnInfoPtr pScrn, SISRegPtr sisReg)
 
     /* Restore FQBQ and GUI timer settings */
     if(pSiS->Chipset == PCI_CHIP_SIS630) {
-       temp1 = pciReadLong(0x00000000, 0x50);
-       temp2 = pciReadLong(0x00000000, 0xA0);
-       if(pciReadLong(0x00000000, 0x00) == 0x06301039) {
+       temp1 = sis_pci_read_host_bridge_u32(0x50);
+       temp2 = sis_pci_read_host_bridge_u32(0xA0);
+       if(sis_pci_read_host_bridge_u32(0x00) == 0x06301039) {
           temp1 &= 0xf0ffffff;
           temp1 |= (sisReg->sisRegsPCI50 & ~0xf0ffffff);
 	  temp2 &= 0xf0ffffff;
@@ -700,8 +698,8 @@ SiS300Restore(ScrnInfoPtr pScrn, SISRegPtr sisReg)
 	  temp2 &= 0x00ffffff;
           temp2 |= (sisReg->sisRegsPCIA0 & ~0x00ffffff);
        }
-       pciWriteLong(0x00000000, 0x50, temp1);
-       pciWriteLong(0x00000000, 0xA0, temp2);
+       sis_pci_write_host_bridge_u32(0x50, temp1);
+       sis_pci_write_host_bridge_u32(0xA0, temp2);
     }
 
     /* Restore panel link/video bridge registers */
@@ -992,7 +990,7 @@ SiS301Restore(ScrnInfoPtr pScrn, SISRegPtr sisReg)
     Part4max = 0x1b;
 
     SiSRegInit(pSiS->SiS_Pr, pSiS->RelIO + 0x30);
-    SiSSetLVDSetc(pSiS->SiS_Pr, 0);
+    SiSSetLVDSetc(pSiS->SiS_Pr);
     SiS_GetVBType(pSiS->SiS_Pr);
     SiS_DisableBridge(pSiS->SiS_Pr);
     SiS_UnLockCRT2(pSiS->SiS_Pr);
@@ -1086,7 +1084,7 @@ SiS301BRestore(ScrnInfoPtr pScrn, SISRegPtr sisReg)
     } /* TODO for 307 */
 
     SiSRegInit(pSiS->SiS_Pr, pSiS->RelIO + 0x30);
-    SiSSetLVDSetc(pSiS->SiS_Pr, 0);
+    SiSSetLVDSetc(pSiS->SiS_Pr);
     SiS_GetVBType(pSiS->SiS_Pr);
     SiS_DisableBridge(pSiS->SiS_Pr);
     SiS_UnLockCRT2(pSiS->SiS_Pr);
@@ -1195,7 +1193,7 @@ SiSLVDSChrontelRestore(ScrnInfoPtr pScrn, SISRegPtr sisReg)
     int i;
 
     SiSRegInit(pSiS->SiS_Pr, pSiS->RelIO + 0x30);
-    SiSSetLVDSetc(pSiS->SiS_Pr, 0);
+    SiSSetLVDSetc(pSiS->SiS_Pr);
     SiS_GetVBType(pSiS->SiS_Pr);
     SiS_DisableBridge(pSiS->SiS_Pr);
     if(pSiS->ChipType == SIS_730) {
